/**
 * EasyBeans
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: CommonMetadataMerge.java 4672 2009-02-20 15:24:30Z sauthieg $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.ee.metadata.ejbjar.impl.xml.helper;

import java.util.Collection;

import org.ow2.util.ee.deploy.api.deployable.EJBDeployable;
import org.ow2.util.ee.metadata.common.api.ICommonClassMetadata;
import org.ow2.util.ee.metadata.common.api.ICommonFieldMetadata;
import org.ow2.util.ee.metadata.common.api.ICommonMethodMetadata;
import org.ow2.util.ee.metadata.common.api.interfaces.IEnvironmentRefAccessor;
import org.ow2.util.ee.metadata.common.impl.xml.merge.MetadataMerge;
import org.ow2.util.ee.metadata.ejbjar.api.IEjbJarClassMetadata;
import org.ow2.util.ee.metadata.ejbjar.api.IEjbJarDeployableMetadata;
import org.ow2.util.ee.metadata.ejbjar.api.IEjbJarFieldMetadata;
import org.ow2.util.ee.metadata.ejbjar.api.IEjbJarMethodMetadata;

/**
 * Defines common stuff that can be used by merger of Deployment Descriptor into
 * the metadata.
 * @param <E> an implementation of EJBDeployable
 * @param <D> an implementation of IEjbJarDeployableMetadata
 * @param <C> an implementation of IEjbJarClassMetadata
 * @param <M> an implementation of IEjbJarMethodMetadata
 * @param <F> an implementation of IEjbJarFieldMetadata
 * @author Florent BENOIT
 */
public class CommonMetadataMerge<
    E extends EJBDeployable<E>,
    D extends IEjbJarDeployableMetadata<E, D, C, M, F>,
    C extends IEjbJarClassMetadata<E, D, C, M, F>,
    M extends IEjbJarMethodMetadata<E, D, C, M, F>,
    F extends IEjbJarFieldMetadata<E, D, C, M, F>> extends MetadataMerge {

    /**
     * Metadata for an ejb-jar.
     */
    private D ejbMetadata = null;

    /**
     * Logger.
     */
    //private static Log logger = LogFactory.getLog(CommonMetadataMerge.class);

    /**
     * Constructor that can be used by subclass.
     * @param ejbMetadata the metadata corresponding to an EJB-JAR file.
     */
    protected CommonMetadataMerge(final D ejbMetadata) {
        this.ejbMetadata = ejbMetadata;
    }

    /**
     * @return the EJB metadata of this merger.
     */
    public D getEjbJarDeployableMetadata() {
        return ejbMetadata;
    }

    @Override
    public String findDefaultClassForEnvironment(final IEnvironmentRefAccessor env) {
        return null;
    }

    @Override
    public ICommonClassMetadata<?, ?, ?> getClassMetadata(final String className) {
        return ejbMetadata.getScannedClassMetadata(className);
    }

    /**
     * @return A collection of all ClassMetadata of the merged object.
     */
    protected Collection<? extends ICommonClassMetadata> getAllClassMetadatas() {
        throw new UnsupportedOperationException("EjbJar does not supports metadata browsing.");
    }

    /**
     * @return A collection of all MethodMetadata of the merged object.
     */
    protected Collection<? extends ICommonMethodMetadata> getAllMethodMetadatas() {
        throw new UnsupportedOperationException("EjbJar does not supports metadata browsing.");
    }

    /**
     * @return A collection of all FieldMetadata of the merged object.
     */
    protected Collection<? extends ICommonFieldMetadata> getAllFieldMetadatas() {
        throw new UnsupportedOperationException("EjbJar does not supports metadata browsing.");
    }


}
